set more off


* Load Data

	
	use "$data/long_final.dta", clear
	
	*for now keep only panel observations
keep if panel == 1

*drop people who aren't household members in all rounds
forvalues i = 1/4 {
    drop if hhmem__r`i' == 3

	}
	
	

* Cleaning
	
	rename *_ *
	rename *sept* *sep*
	gen all = 1
	gen longrecall = 0
	replace longrecall = 1 if recall=="12m"
	*gen proxy = pid != 1																// confirm later, placeholder assuming respondent is in pid==1, but might not be true
	gen first3m = 0
	replace first3m = 1 if treatment == 1
	*gen last = pid==3
	*egen proxy = rowmax(proxy_r1 proxy_r2 proxy_r3 proxy_r4)
	*egen proxy2 = rowmin(proxy_r1 proxy_r2 proxy_r3 proxy_r4)
	gen proxy = proxy_r4
	
* Prepping some variables

	sum hours_total, d
	replace hours_total = r(p99) if hours_total > r(p99) & hours_total!=.  				// winsorizing hours worked
	replace hours_total = hours_total / 100	
	
	sum hours_q, d
	replace hours_q = r(p99) if hours_q > r(p99) & hours_q!=.  							// winsorizing hours worked
	replace hours_q = hours_q / 100	
	
	sum hours_qb, d
	replace hours_qb = r(p99) if hours_qb > r(p99) & hours_qb!=.  						// winsorizing hours worked
	replace hours_qb = hours_qb / 100	
	
	sum hours_max_qb, d
	replace hours_max_qb = r(p99) if hours_max_qb > r(p99) & hours_max_qb!=.  			// winsorizing hours worked
	replace hours_max_qb = hours_max_qb / 100	

	forvalues i = 1/4 {
			
		sum hours_q`i', d
		replace hours_q`i'= r(p99) if `var'`i'> r(p99) & hours_q`i'!=. 
		replace hours_q`i' = hours_q`i' / 100
			
		}
	
	sum age if proxy==1, d
	gen temp = age < r(p50)	
	sum age if proxy==0, d
	gen young = age<=r(p50)
	replace young = temp if proxy==1
	drop temp
	

	*exit
	
	gen age1 = 0
	replace age1 = 1 if age < 25
	gen age2 = 0
	replace age2 = 1 if age >= 25 & age < 35
	gen age3 = 0
	replace age3 = 1 if age >= 35 & age < 50
	gen age4 = 0
	replace age4 = 1 if age >= 50 & !missing(age)

	gen age_grp = 0
	replace age_grp = 1 if age < 25
	replace age_grp = 2 if age >= 25 & age < 35
	replace age_grp = 3 if age >= 35 & age < 50
	replace age_grp = 4 if age >= 50 & !missing(age)

	gen age1_resp_r4 = 0
	replace age1_resp_r4 = 1 if age_resp_r4 < 25
	gen age2_resp_r4 = 0
	replace age2_resp_r4 = 1 if age_resp_r4 >= 25 & age_resp_r4 < 35
	gen age3_resp_r4 = 0
	replace age3_resp_r4 = 1 if age_resp_r4 >= 35 & age_resp_r4 < 50
	gen age4_resp_r4 = 0
	replace age4_resp_r4 = 1 if age_resp_r4 >= 50 & !missing(age_resp_r4)

	gen age_grp_resp_r4 = 0
	replace age_grp_resp_r4 = 1 if age_resp_r4 < 25
	replace age_grp_resp_r4 = 2 if age_resp_r4 >= 25 & age_resp_r4 < 35
	replace age_grp_resp_r4 = 3 if age_resp_r4 >= 35 & age_resp_r4 < 50
	replace age_grp_resp_r4 = 4 if age_resp_r4 >= 50 & !missing(age_resp_r4)
	
	bys hhid: gen mmbrs = _N / 2
	
* Treatment Interactions	
	gen longrecallxfirst3m = longrecall * first3m
	gen longrecallxproxy = longrecall * proxy
	gen longrecallxself = longrecall * (proxy==0)
	gen longrecallxfemale = longrecall * female
	gen longrecallxmale = longrecall * (female==0)
	gen longrecallxyoung = longrecall * young
	gen longrecallxold = longrecall * (young==0)
	*gen longrecallxlast = longrecall * last
	
	gen longrecallxage1 = longrecall * age1
	gen longrecallxage2 = longrecall * age2
	gen longrecallxage3 = longrecall * age3
	gen longrecallxage4 = longrecall * age4

	gen longrecallxfemaleresp = longrecall * female_resp_r4
	gen longrecallxmaleresp = longrecall * (female_resp_r4==0)
	
	gen longrecallxage1resp = longrecall * age1_resp_r4
	gen longrecallxage2resp = longrecall * age2_resp_r4
	gen longrecallxage3resp = longrecall * age3_resp_r4
	gen longrecallxage4resp = longrecall * age4_resp_r4
	
* Get Correct Sample


	*preserve
	gen keep = .
	replace keep = 1 if first3m == 0 & longrecall == 1
	replace keep = 1 if first3m == 1 & longrecall == 0
	*keep if (first3m==0 & longrecall==1) | (first3m==1 & longrecall==0)

	keep if keep == 1
	
	rename worked_q worked_qa 
	rename numjobtot numjobtota 
	rename worked_nummnths_q worked_nummnths_qa 
	rename hours_q hours_qa 
	rename type_hhf_q type_hhf_qa 
	rename type_hhb_q type_hhb_qa 
	rename type_wage_q type_wage_qa
	

	
* Gen indvidual id

	egen iid = group(hhid mem)	
	
*education of respondent

gen dum1 = school_years if pid == 1
gen dum2 = school_level if pid == 1

bys hhid: egen school_years_head = max(dum1)
bys hhid: egen school_level_head = max(dum2)
	
gen school_high_head = 0 if school_level_head < 8
replace school_high_head = 1 if school_level_head >= 8 & !missing(school_level_head)  

gen school_low_head = 1 if school_level_head < 8
replace school_low_head = 0 if school_level_head >= 8 & !missing(school_level_head)  

gen longrecallxedlowhead = longrecall * school_low_head
gen longrecallxedhighhead = longrecall * school_high_head
	

** TABLE 1: Test of Difference between short and long recall on annual totals
** TABLE 1B: Heterogeneity

local cluster hhid
local controls i.female##i.age_grp##i.proxy
local controls2 i.female##i.age_grp


		foreach Y in a b {
		    		
		local onum = 1
					
		foreach oc in worked_q`Y' numjobtot`Y' worked_nummnths_q`Y' hours_q`Y' type_hhf_q`Y' type_hhb_q`Y' type_wage_q`Y' {
			
			reg `oc' longrecall `controls', vce(cluster `cluster') 
			mat res = e(b)			
			
			local beta1 = res[1,1]		
			sum `oc' if longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			local b1 = `beta1' / `m1'		
			estadd scalar bw1 = round(`b1', .001)			
			estadd scalar m1 = round(`m1', .001)	
			eststo r`onum'`Y'
			

			reg `oc' longrecallxself longrecallxproxy  `controls', vce(cluster `cluster') 
			mat res = e(b)	
			
			local beta1 = res[1,1]
			local beta2 = res[1,2]			
			sum `oc' if proxy==0 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if proxy==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 				
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'	
			test longrecallxself = longrecallxproxy
			estadd scalar p1 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)				
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)	
			estadd local samp
			eststo sx`onum'`Y'								

			reg `oc' longrecallxmale longrecallxfemale `controls2' if proxy==0, vce(cluster `cluster') 
			mat res = e(b)	
			local beta1 = res[1,1]
			local beta2 = res[1,2]	
		
			sum `oc' if female==0 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if female==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 				
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'	
			test longrecallxmale = longrecallxfemale
			estadd scalar p1 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)	
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)
			estadd local samp
			estadd local samp2
			eststo zx`onum'`Y'
			
			rename longrecallxmale longrecallxmaleold 
			rename longrecallxmaleresp longrecallxmale
			rename longrecallxfemale longrecallxfemaleold 
			rename longrecallxfemaleresp longrecallxfemale
			
			reg `oc' longrecallxmale longrecallxfemale female_resp_r4 `controls2' if proxy==1, vce(cluster `cluster') 
			mat res = e(b)	
			
			local beta1 = res[1,1]
			local beta2 = res[1,2]		
			sum `oc' if female_resp_r4==0 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if female_resp_r4==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 				
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'	
			test longrecallxmale = longrecallxfemale
			estadd scalar p1 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)				
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)	
			estadd local samp
			estadd local samp2
			eststo zxb`onum'`Y'	
			
			rename longrecallxmale longrecallxmaleresp 
			rename longrecallxmaleold longrecallxmale 
			rename longrecallxfemale longrecallxfemaleresp 
			rename longrecallxfemaleold longrecallxfemale 
			
			reg `oc' longrecallxmale longrecallxfemale `controls2' if proxy==1, vce(cluster `cluster') 
			mat res = e(b)	
			
			local beta1 = res[1,1]
			local beta2 = res[1,2]		
			sum `oc' if female==0 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if female==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 				
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'	
			test longrecallxmale = longrecallxfemale
			estadd scalar p1 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)				
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)		
			estadd local samp
			estadd local samp2
			eststo zxc`onum'`Y'	

			reg `oc' longrecallxage1 longrecallxage2 longrecallxage3 longrecallxage4 `controls2' if proxy==0, vce(cluster `cluster') 
			mat res = e(b)	
			
			local beta1 = res[1,1]
			local beta2 = res[1,2]	
			local beta3 = res[1,3]
			local beta4 = res[1,4]
			sum `oc' if age1==1 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if age2==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 
			sum `oc' if age3==1 & longrecall==0 & e(sample) == 1
			local m3 = r(mean) 
			sum `oc' if age4==1 & longrecall==0 & e(sample) == 1
			local m4 = r(mean) 
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'
			local b3 = `beta3' / `m3'
			local b4 = `beta4' / `m4'
			test longrecallxage1 = longrecallxage2
			estadd scalar p1 = r(p)
			test longrecallxage1 = longrecallxage3
			estadd scalar p2 = r(p)
			test longrecallxage1 = longrecallxage4
			estadd scalar p3 = r(p)
			test longrecallxage2 = longrecallxage3
			estadd scalar p4 = r(p)
			test longrecallxage2 = longrecallxage4
			estadd scalar p5 = r(p)
			test longrecallxage3 = longrecallxage4
			estadd scalar p6 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)		
			estadd scalar bw3 = round(`b3', .001)		
			estadd scalar bw4 = round(`b4', .001)		
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)		
			estadd scalar m3 = round(`m3', .001)		
			estadd scalar m4 = round(`m4', .001)		
			estadd local samp
			estadd local samp2
			eststo qx`onum'`Y'	

			rename longrecallxage1 longrecallxage1old 
			rename longrecallxage1resp longrecallxage1
			rename longrecallxage2 longrecallxage2old 
			rename longrecallxage2resp longrecallxage2
			rename longrecallxage3 longrecallxage3old 
			rename longrecallxage3resp longrecallxage3
			rename longrecallxage4 longrecallxage4old 
			rename longrecallxage4resp longrecallxage4
			
			reg `oc' longrecallxage1 longrecallxage2 longrecallxage3 longrecallxage4 age1_resp_r4 age2_resp_r4 age3_resp_r4 age4_resp_r4 `controls2' if proxy==1, vce(cluster `cluster') 
			mat res = e(b)	
			
			local beta1 = res[1,1]
			local beta2 = res[1,2]
			local beta3 = res[1,3]
			local beta4 = res[1,4]
			sum `oc' if age1_resp_r4==1 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if age2_resp_r4==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 
			sum `oc' if age3_resp_r4==1 & longrecall==0 & e(sample) == 1
			local m3 = r(mean) 
			sum `oc' if age4_resp_r4==1 & longrecall==0 & e(sample) == 1
			local m4 = r(mean) 
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'
			local b3 = `beta3' / `m3'
			local b4 = `beta4' / `m4'
			test longrecallxage1 = longrecallxage2
			estadd scalar p1 = r(p)
			test longrecallxage1 = longrecallxage3
			estadd scalar p2 = r(p)
			test longrecallxage1 = longrecallxage4
			estadd scalar p3 = r(p)
			test longrecallxage2 = longrecallxage3
			estadd scalar p4 = r(p)
			test longrecallxage2 = longrecallxage4
			estadd scalar p5 = r(p)
			test longrecallxage3 = longrecallxage4
			estadd scalar p6 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)		
			estadd scalar bw3 = round(`b3', .001)		
			estadd scalar bw4 = round(`b4', .001)		
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)		
			estadd scalar m3 = round(`m3', .001)		
			estadd scalar m4 = round(`m4', .001)	
			estadd local samp
			estadd local samp2
			eststo qxb`onum'`Y'	
			
			rename longrecallxage1 longrecallxage1resp
			rename longrecallxage1old longrecallxage1
			rename longrecallxage2 longrecallxage2resp
			rename longrecallxage2old longrecallxage2
			rename longrecallxage3 longrecallxage3resp
			rename longrecallxage3old longrecallxage3
			rename longrecallxage4 longrecallxage4resp
			rename longrecallxage4old longrecallxage4
			
			reg `oc' longrecallxage1 longrecallxage2 longrecallxage3 longrecallxage4 `controls2' if proxy==1, vce(cluster `cluster') 
			mat res = e(b)	
			
			local beta1 = res[1,1]
			local beta2 = res[1,2]
			local beta3 = res[1,3]
			local beta4 = res[1,4]
			sum `oc' if age1==1 & longrecall==0 & e(sample) == 1
			local m1 = r(mean) 	
			sum `oc' if age2==1 & longrecall==0 & e(sample) == 1
			local m2 = r(mean) 
			sum `oc' if age3==1 & longrecall==0 & e(sample) == 1
			local m3 = r(mean) 
			sum `oc' if age4==1 & longrecall==0 & e(sample) == 1
			local m4 = r(mean) 
			local b1 = `beta1' / `m1'
			local b2 = `beta2' / `m2'
			local b3 = `beta3' / `m3'
			local b4 = `beta4' / `m4'
			test longrecallxage1 = longrecallxage2
			estadd scalar p1 = r(p)
			test longrecallxage1 = longrecallxage3
			estadd scalar p2 = r(p)
			test longrecallxage1 = longrecallxage4
			estadd scalar p3 = r(p)
			test longrecallxage2 = longrecallxage3
			estadd scalar p4 = r(p)
			test longrecallxage2 = longrecallxage4
			estadd scalar p5 = r(p)
			test longrecallxage3 = longrecallxage4
			estadd scalar p6 = r(p)
			estadd scalar bw1 = round(`b1', .001)	
			estadd scalar bw2 = round(`b2', .001)		
			estadd scalar bw3 = round(`b3', .001)		
			estadd scalar bw4 = round(`b4', .001)		
			estadd scalar m1 = round(`m1', .001)	
			estadd scalar m2 = round(`m2', .001)		
			estadd scalar m3 = round(`m3', .001)		
			estadd scalar m4 = round(`m4', .001)		
			estadd local samp
			estadd local samp2
			eststo qxc`onum'`Y'		
			

			local onum = `onum' + 1
			
		}
		}

		
		    
			esttab r1b r2b r3b r4b r5b r6b r7b using "$output/table3a.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Worked at all" "Total activities" "Number of months worked" "Hours worked (100s)" "Worked hh farm/ag" "Worked non ag business" "Worked wage") ///
			drop(_cons *female* *age_grp* *proxy*)		///
			varlabels(longrecall "Long Recall" )  ///
			stats(m1 bw1 N r2 , fmt(3 3 0 3 ) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared"  )) ///
			note("Notes: Reported means are of short recall estimates.") nogaps  ///
			label title("Table 3a: Test of Losses from Long Recall Window") replace	
			
			esttab sx1b sx2b sx3b sx4b sx5b sx6b sx7b using "$output/table3b.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Worked at all" "Total activities" "Number of months worked" "Hours worked (100s)" "Worked hh farm/ag" "Worked non ag business" "Worked wage") ///
			keep(longrecall*)		///
			varlabels(longrecallxself "Long Recall X Self-Report" longrecallxproxy "Long Recall X Proxy")  ///
			stats(m1 m2 bw1 bw2 p1 N r2 , fmt(3 3 3 3 3 0 3 ) ///
			label("Mean Self-Report" "Mean Proxy" "Scaled Difference Self-Report" "Scaled Difference Proxy" "P-Val: Self=Proxy" "Observations" "R-squared"  )) ///
			note("Notes: Reported means are of short recall estimates.") nogaps  ///
			label title("Table 3b: Test of Losses from Long Recall Window by Self-Report or Proxy") replace
			
			esttab zx2b zxb2b zxc2b zx3b zxb3b zxc3b using "$output/table4.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Total activities" "Total activities" "Total activities" "Number of months worked" "Number of months worked" "Number of months worked") ///
			keep(longrecall*)		///
			varlabels(longrecallxmale "Long Recall x Male" longrecallxfemale "Long Recall x Female") ///
			stats(samp samp2 m1 m2 bw1 bw2 p1 N r2 , fmt(3 3 3 3 3 3 3 0 3 ) ///
			label("Sample" "Characteristics" "Mean Male" "Mean Female" "Scaled Difference Male" "Scaled Difference Female" "P-Val: Male=Female" "Observations" "R-squared" )) ///
			note("Notes: Reported means are of short recall estimates in indicated group.") nogaps  ///
			label title("Table 4: Long recall losses: Heterogeneity by Gender") replace
			
			esttab qx2b qxb2b qxc2b qx3b qxb3b qxc3b using "$output/table5.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Total activities" "Total activities" "Total activities" "Number of months worked" "Number of months worked" "Number of months worked") ///
			keep(longrecall*)		///
			varlabels(longrecallxage1 "Long Recall x Under 25" longrecallxage2 "Long Recall x 25 - 34" longrecallxage3 "Long Recall x 35 - 49" longrecallxage4 "Long Recall x 50 plus")  ///
			stats(samp samp2 m1 m2 m3 m4 bw1 bw2 bw3 bw4 p1 p2 p3 p4 p5 p6 N r2 , fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 3 ) ///
			label("Sample" "Characteristics" "Mean Under 25" "Mean 25 - 34" "Mean 35 - 49" "Mean 50 plus" "Scaled Difference Under 25" "Scaled Difference 25 -34" "Scaled Difference 35 - 49" "Scaled Difference 50 plus" ///
			"P-Val: U25=25 -34" "P-Val: U25=35 - 49" "P-Val: U25=50plus" "P-Val: 25 - 34=35 - 49" "P-Val: 25 - 34=50 plus" "P-Val: 35 - 49=50plus"  "Observations" "R-squared" )) ///
			note("Notes: Reported means are of short recall estimates in indicated group.") nogaps  ///
			label title("Table 5: Long recall losses: Heterogeneity by Age Group") replace

			esttab r1a r2a r3a r4a r5a r6a r7a using "$output/tableA2.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Worked at all" "Total activities" "Number of months worked" "Hours worked (100s)" "Worked hh farm/ag" "Worked non ag business" "Worked wage") ///
			drop(_cons *female* *age_grp* *proxy*)		///
			varlabels(longrecall "Long Recall" )  ///
			stats(m1 bw1 N r2 , fmt(3 3 0 3 ) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared"  )) ///
			note("Notes: Reported means are of short recall estimates.") nogaps  ///
			label title("Appendix Table 2: Test of Losses from Long Recall Window") replace	
			
			esttab zx1b zxb1b zxc1b zx4b zxb4b zxc4b using "$output/tableA4.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Worked at all" "Worked at all" "Worked at all" "Hours worked (100s)" "Hours worked (100s)" "Hours worked (100s)") ///
			keep(longrecall*)		///
			varlabels(longrecallxmale "Long Recall x Male" longrecallxfemale "Long Recall x Female") ///
			stats(samp samp2 m1 m2 bw1 bw2 p1 N r2 , fmt(3 3 3 3 3 3 3 0 3 ) ///
			label("Sample" "Characteristics" "Mean Male" "Mean Female" "Scaled Difference Male" "Scaled Difference Female" "P-Val: Male=Female" "Observations" "R-squared" )) ///
			note("Notes: Reported means are of short recall estimates in indicated group.") nogaps  ///
			label title("Appendix Table 4: Long recall losses: Heterogeneity by Gender") replace
			
			esttab qx1b qxb1b qxc1b qx4b qxb4b qxc4b using "$output/tableA5.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Worked at all" "Worked at all" "Worked at all" "Hours worked (100s)" "Hours worked (100s)" "Hours worked (100s)") ///
			keep(longrecall*)		///
			varlabels(longrecallxage1 "Long Recall x Under 25" longrecallxage2 "Long Recall x 25 - 34" longrecallxage3 "Long Recall x 35 - 49" longrecallxage4 "Long Recall x 50 plus")  ///
			stats(samp samp2 m1 m2 m3 m4 bw1 bw2 bw3 bw4 p1 p2 p3 p4 p5 p6 N r2 , fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 0 3 ) ///
			label("Sample" "Characteristics" "Mean Under 25" "Mean 25 - 34" "Mean 35 - 49" "Mean 50 plus" "Scaled Difference Under 25" "Scaled Difference 25 -34" "Scaled Difference 35 - 49" "Scaled Difference 50 plus" ///
			"P-Val: U25=25 -34" "P-Val: U25=35 - 49" "P-Val: U25=50plus" "P-Val: 25 - 34=35 - 49" "P-Val: 25 - 34=50 plus" "P-Val: 35 - 49=50plus"  "Observations" "R-squared" )) ///
			note("Notes: Reported means are of short recall estimates in indicated group.") nogaps  ///
			label title("Appendix Table 5: Long recall losses: Heterogeneity by Age Group") replace
		
			

estimates clear

	
** Next set: Test of Differences by quarter
	
		local months = "q1 q2 q3 q4"
		local onum = 1
		foreach oc in worked worked_nummnths numjob hours type_hhf type_hhb type_wage {
			
			local mcount = 1
			foreach month in `months'{
				
				gen tx`mcount' = longrecall											
			
				reghdfe `oc'_`month' longrecall `controls', a(all) vce(cluster `cluster') 			// First time for table version
				mat res = e(b)			
				local beta1 = res[1,1]		
				sum `oc'_`month' if e(sample) & longrecall == 0
				local m1 = r(mean) 	
				local b1 = `beta1' / `m1'		
				estadd scalar bw1 = round(`b1', .001)			
				estadd scalar m1 = round(`m1', .001)	
				eststo s`onum'_`mcount'
				
				reghdfe `oc'_`month'  tx`mcount' `controls', a(all) vce(cluster `cluster') 			// Second time for figure version
				eststo r`onum'_`mcount'
					
				local mcount = `mcount' + 1
			}
		
		drop tx*
		local onum = `onum' + 1
	
		}
	
			esttab s1_1 s1_2 s1_3 s1_4 using "$output/table_quarterly1.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2  , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared" )) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on any work") replace	
			
	
			
			esttab s2_1 s2_2 s2_3 s2_4  using "$output/table_quarterly2.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///				
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on number of months worked") replace	
			

			
			esttab s3_1 s3_2 s3_3 s3_4   using "$output/table_quarterly3.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on number of activities") replace	
			

			
			esttab s4_1 s4_2 s4_3 s4_4   using "$output/table_quarterly4.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on hours worked") replace	
			

** Next set: Test of Differences by quarter
	
	preserve
		keep if proxy==0
	
		local months = "q1 q2 q3 q4"
		local onum = 1
		foreach oc in worked worked_nummnths numjob hours type_hhf type_hhb type_wage {
			
			local mcount = 1
			foreach month in `months'{
				
				gen tx`mcount' = longrecall											
			
				reghdfe `oc'_`month' longrecall `controls', a(all) vce(cluster `cluster') 			// First time for table version
				mat res = e(b)			
				local beta1 = res[1,1]		
				sum `oc'_`month' if e(sample) & longrecall == 0
				local m1 = r(mean) 	
				local b1 = `beta1' / `m1'		
				estadd scalar bw1 = round(`b1', .001)			
				estadd scalar m1 = round(`m1', .001)	
				eststo s`onum'_`mcount'
				
				reghdfe `oc'_`month'  tx`mcount' `controls', a(all) vce(cluster `cluster') 			// Second time for figure version
				eststo r`onum'_`mcount'
					
				local mcount = `mcount' + 1
			}
		
		drop tx*
		local onum = `onum' + 1
	
		}
	
			esttab s1_1 s1_2 s1_3 s1_4 using "$output/table_quarterly1b.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2  , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared" )) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on any work - Self Report Only") replace	
			
	
			
			esttab s2_1 s2_2 s2_3 s2_4  using "$output/table_quarterly2b.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///				
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on number of months worked - Self Report Only") replace	
			

			
			esttab s3_1 s3_2 s3_3 s3_4   using "$output/table_quarterly3b.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on number of activities - Self Report Only") replace	
			

			
			esttab s4_1 s4_2 s4_3 s4_4   using "$output/table_quarterly4b.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on hours worked - Self Report Only") replace	
	
	restore
	

** Next set: Test of Differences by quarter
	
	preserve 
		keep if proxy==1
		
		local months = "q1 q2 q3 q4"
		local onum = 1
		foreach oc in worked worked_nummnths numjob hours type_hhf type_hhb type_wage {
			
			local mcount = 1
			foreach month in `months'{
				
				gen tx`mcount' = longrecall											
			
				reghdfe `oc'_`month' longrecall `controls', a(all) vce(cluster `cluster') 			// First time for table version
				mat res = e(b)			
				local beta1 = res[1,1]		
				sum `oc'_`month' if e(sample) & longrecall == 0
				local m1 = r(mean) 	
				local b1 = `beta1' / `m1'		
				estadd scalar bw1 = round(`b1', .001)			
				estadd scalar m1 = round(`m1', .001)	
				eststo s`onum'_`mcount'
				
				reghdfe `oc'_`month'  tx`mcount' `controls', a(all) vce(cluster `cluster') 			// Second time for figure version
				eststo r`onum'_`mcount'
					
				local mcount = `mcount' + 1
			}
		
		drop tx*
		local onum = `onum' + 1
	
		}
	
			esttab s1_1 s1_2 s1_3 s1_4 using "$output/table_quarterly1c.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2  , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared" )) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on any work - Proxy Report Only") replace	
			
	
			
			esttab s2_1 s2_2 s2_3 s2_4  using "$output/table_quarterly2c.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///				
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on number of months worked - Proxy Report Only") replace	
			

			
			esttab s3_1 s3_2 s3_3 s3_4   using "$output/table_quarterly3c.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on number of activities - Proxy Report Only") replace	
			

			
			esttab s4_1 s4_2 s4_3 s4_4   using "$output/table_quarterly4c.csv", ///
			cells(b(fmt(%9.3f)) se(nopar fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Quarter 1" "Quarter 2" "Quarter 3" "Quarter 4") ///
			keep(longrecall)		///					
			varlabels(longrecall "Long Recall (0/1)" )   ///
			stats(m1 bw1 N r2 , fmt(3 3 0  3) ///
			label("Mean Short Recall" "Scaled Difference" "Observations" "R-squared")) ///
			note( ) nogaps  ///
			label title("Long recall by quarter on hours worked - Proxy Report Only") replace	
			
restore 