* Load Data


	
	use "$data/long_final.dta", clear	
	
	*for now keep only panel observations
keep if panel == 1

local cluster hhid
local controls i.female##i.age_grp##i.proxy
local controls2 i.female##i.age_grp

keep if panel == 1

*drop people who aren't household members in all rounds
forvalues i = 1/4 {
    drop if hhmem__r`i' == 3

	}
	
	

* Cleaning
	
	rename *_ *
	rename *sept* *sep*
	gen all = 1
	gen longrecall = 0
	replace longrecall = 1 if recall=="12m"
	*gen proxy = pid != 1																// confirm later, placeholder assuming respondent is in pid==1, but might not be true
	gen first3m = 0
	replace first3m = 1 if treatment == 1
	*gen last = pid==3
	*egen proxy = rowmax(proxy_r1 proxy_r2 proxy_r3 proxy_r4)
	*egen proxy2 = rowmin(proxy_r1 proxy_r2 proxy_r3 proxy_r4)
	gen proxy = proxy_r4
	
* Prepping some variables

	sum hours_total, d
	replace hours_total = r(p99) if hours_total > r(p99) & hours_total!=.  				// winsorizing hours worked
	replace hours_total = hours_total / 100	
	
	sum hours_q, d
	replace hours_q = r(p99) if hours_q > r(p99) & hours_q!=.  							// winsorizing hours worked
	replace hours_q = hours_q / 100	
	
	sum hours_qb, d
	replace hours_qb = r(p99) if hours_qb > r(p99) & hours_qb!=.  						// winsorizing hours worked
	replace hours_qb = hours_qb / 100	
	
	sum hours_max_qb, d
	replace hours_max_qb = r(p99) if hours_max_qb > r(p99) & hours_max_qb!=.  			// winsorizing hours worked
	replace hours_max_qb = hours_max_qb / 100	

	forvalues i = 1/4 {
			
		sum hours_q`i', d
		replace hours_q`i'= r(p99) if `var'`i'> r(p99) & hours_q`i'!=. 
		replace hours_q`i' = hours_q`i' / 100
			
		}
	
	sum age if proxy==1, d
	gen temp = age < r(p50)	
	sum age if proxy==0, d
	gen young = age<=r(p50)
	replace young = temp if proxy==1
	drop temp
	

	*exit
	
	gen age1 = 0
	replace age1 = 1 if age < 25
	gen age2 = 0
	replace age2 = 1 if age >= 25 & age < 35
	gen age3 = 0
	replace age3 = 1 if age >= 35 & age < 50
	gen age4 = 0
	replace age4 = 1 if age >= 50 & !missing(age)

	gen age_grp = 0
	replace age_grp = 1 if age < 25
	replace age_grp = 2 if age >= 25 & age < 35
	replace age_grp = 3 if age >= 35 & age < 50
	replace age_grp = 4 if age >= 50 & !missing(age)

	gen age1_resp_r4 = 0
	replace age1_resp_r4 = 1 if age_resp_r4 < 25
	gen age2_resp_r4 = 0
	replace age2_resp_r4 = 1 if age_resp_r4 >= 25 & age_resp_r4 < 35
	gen age3_resp_r4 = 0
	replace age3_resp_r4 = 1 if age_resp_r4 >= 35 & age_resp_r4 < 50
	gen age4_resp_r4 = 0
	replace age4_resp_r4 = 1 if age_resp_r4 >= 50 & !missing(age_resp_r4)

	gen age_grp_resp_r4 = 0
	replace age_grp_resp_r4 = 1 if age_resp_r4 < 25
	replace age_grp_resp_r4 = 2 if age_resp_r4 >= 25 & age_resp_r4 < 35
	replace age_grp_resp_r4 = 3 if age_resp_r4 >= 35 & age_resp_r4 < 50
	replace age_grp_resp_r4 = 4 if age_resp_r4 >= 50 & !missing(age_resp_r4)
	
	bys hhid: gen mmbrs = _N / 2

gen askedfirst = 1 if first3m == 1 & longrecall == 0
replace askedfirst = 0 if first3m == 1 & longrecall == 1
replace askedfirst = 1 if first3m == 0 & longrecall == 1
replace askedfirst = 0 if first3m == 0 & longrecall == 0

	
	rename worked_q worked_qa 
	rename numjobtot numjobtota 
	rename worked_nummnths_q worked_nummnths_qa 
	rename hours_q hours_qa 
	rename type_hhf_q type_hhf_qa 
	rename type_hhb_q type_hhb_qa 
	rename type_wage_q type_wage_qa

label var askedfirst "Asked first"
	
		foreach Y in a b {
		    
		local onum = 1
		
		foreach oc in worked_q`Y' numjobtot`Y' worked_nummnths_q`Y' hours_q`Y' {
			
			reg `oc' askedfirst `controls' if longrecall == 0, vce(cluster `cluster') 
			mat res = e(b)			
			local beta1 = res[1,1]		
			sum `oc' if first3m == 0 & e(sample) == 1
			local m1 = r(mean) 	
			local b1 = `beta1' / `m1'		
			estadd scalar bw1 = round(`b1', .001)			
			estadd scalar m1 = round(`m1', .001)	
			eststo r`onum'`Y'
			
			reg `oc' askedfirst `controls' if longrecall == 1, vce(cluster `cluster') 
			mat res = e(b)			
			local beta1 = res[1,1]		
			sum `oc' if first3m == 0 & e(sample) == 1
			local m1 = r(mean) 	
			local b1 = `beta1' / `m1'		
			estadd scalar bw1 = round(`b1', .001)			
			estadd scalar m1 = round(`m1', .001)	
			eststo s`onum'`Y'
			
			local onum = `onum' + 1
			
		}
		}
			esttab r1b r2b r3b r4b s1b s2b s3b s4b using "$output/tableA3.csv", ///
			cells(b(fmt(%9.3f) star) se(par fmt(%9.3f))) ///
			starlevels(* .1 ** .05 *** .01) style(tex)  ///
			mlabel("Worked at all" "Number of months worked" "Total activities" "Hours worked (100s)" "Worked at all" "Number of months worked" "Total activities" "Hours worked (100s)") ///
			keep(askedfirst*)			///
			varlabels(askedfirst "Asked first" )  ///
			stats(m1 bw1 N r2 , fmt(3 3 0 3 ) ///
			label("Mean 12 month questions first" "Scaled Difference" "Observations" "R-squared"  )) ///
			note("Notes: Columns 1 - 4 show the impact of asking the quarterly recall first on the quarterly recall measures. Columns 5 - 8 show the impact of asking the long recall questions first on the long recall measures. Other specification notes are as in the main tables.") nogaps  ///
			label title("Appendix Table 3: Test of Losses from Order of Modules") replace	
		
		