

use "$data/merged_long_data_attrit.dta", clear
drop if treatment == 0

local cluster hhid

tab treatment, gen(treat)

gen female = 1 if gender == 0
replace female = 0 if gender == 1

gen panel_person = 1 if panel == 1
replace panel_person = 0 if (hhmem__r1 == 3 | hhmem__r2 == 3 | hhmem__r3 == 3 | hhmem__r4 == 3) & panel == 1
replace panel_person = 0 if missing(hhmem__r4) & panel_person == 1

gen rel_head = 0 
replace rel_head = 1 if rel_tohead == 1

gen rel_spouse = 0
replace rel_spouse = 1 if rel_tohead == 2

gen rel_child = 0
replace rel_child = 1 if rel_tohead == 3

gen rel_other = 0
replace rel_other = 1 if rel_tohead >= 4


gen married_monog = 0
replace married_monog = 1 if mar_status == 1

gen married_poly = 0
replace married_poly = 1 if mar_status == 2


gen samp1 = 1 if pid == 1 & treatment != 0

gen samp2 = 1 if pid == 1 & panel == 1 & panel_person == 1
gen samp3 = 1 if pid == 1 & panel == 1 & panel_person == 1 & treatment == 1
gen samp4 = 1 if pid == 1 & panel == 1 & panel_person == 1 & treatment == 2


*Table 1 - Main sum stats*
putexcel set "$output\tables_seasonality_paper.xlsx", sheet("Table1") modify 

forvalues i = 2/5 {
    
	if `i' == 2 {
	    local col = "B"
	}
	if `i' == 3 {
	    local col = "C"
	}
	if `i' == 4 {
	    local col = "D"
	}
	if `i' == 5 {
	    local col = "E"
	}
	
	local j = 10
	foreach var in female age married_monog married_poly school_years {
	    
		if `i' >= 2 & `i' <= 4 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}
		if `i' == 5 {
		    
			reg `var' treat1 treat2 if samp2 == 1, nocons vce(cluster hhid) 
			test treat1 = treat2
			putexcel `col'`j' = `r(p)'			

			}
			local j = `j' + 1		
		}
		
		if `i' >= 2 & `i' <= 4 {

			sum female if samp`i' == 1
			putexcel `col'`j' = `r(N)'
		}
		
	}


	
drop samp*
gen samp1 = 1 if pid != 1 & treatment != 0

gen samp2 = 1 if pid != 1 & panel == 1 & panel_person == 1
gen samp3 = 1 if pid != 1 & panel == 1 & panel_person == 1 & treatment == 1
gen samp4 = 1 if pid != 1 & panel == 1 & panel_person == 1 & treatment == 2
 

 

forvalues i = 2/5 {
    
	if `i' == 2 {
	    local col = "B"
	}
	if `i' == 3 {
	    local col = "C"
	}
	if `i' == 4 {
	    local col = "D"
	}
	if `i' == 5 {
	    local col = "E"
	}


	
	local j = 18
	foreach var in female age married_monog married_poly school_years {
	    
		if `i' >= 2 & `i' <= 4 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}
		if `i' == 5 {
		    
			reg `var' treat1 treat2 if samp2 == 1, nocons vce(cluster hhid) 
			test treat1 = treat2
			putexcel `col'`j' = `r(p)'			

			}
			local j = `j' + 1		
		}
		
		if `i' >= 2 & `i' <= 4 {

			sum female if samp`i' == 1
			putexcel `col'`j' = `r(N)'
		}
		
	}


use "$data/merged_data_attrit.dta", clear

drop if treatment == 0

local cluster hhid

tab treatment, gen(treat)

gen samp1 = 1 if treatment != 0

gen samp2 = 1 if panel == 1
gen samp3 = 1 if panel == 1 & treatment == 1
gen samp4 = 1 if panel == 1 & treatment == 2

forvalues i = 2/5 {
    
	if `i' == 2 {
	    local col = "B"
	}
	if `i' == 3 {
	    local col = "C"
	}
	if `i' == 4 {
	    local col = "D"
	}
	if `i' == 5 {
	    local col = "E"
	}
	
	local j = 4
	foreach var in hhsize numadults numchildren {
	    
		if `i' >= 2 & `i' <= 4 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}
		if `i' == 5 {
		    
			reg `var' treat1 treat2 if samp2 == 1, nocons vce(cluster hhid) 
			test treat1 = treat2
			putexcel `col'`j' = `r(p)'			

			}
			local j = `j' + 1		
		}
		
		if `i' >= 2 & `i' <= 4 {

			sum hhsize if samp`i' == 1
			putexcel `col'`j' = `r(N)'
		}
		
	}


putexcel A1:E1, merge 
putexcel A1:E1, hcenter bold border(bottom)
putexcel A2:E2, hcenter vcenter txtwrap
putexcel A1 = "Table 1: Summary statisics, attrition, and balance"

putexcel B2 = "Full sample"	
putexcel C2 = "Short recall first"	
putexcel D2 = "Long recall first"	
putexcel E2 = "P-value: Short recall = Long recall"	

putexcel A3:E3, italic border(bottom)
putexcel A3 = "Households"
putexcel A4 = "Household size"
putexcel A5 = "Number of adults"
putexcel A6 = "Number of children"
putexcel A7 = "Sample size"

putexcel A9:E9, italic border(bottom)
putexcel A9 = "Household head (designated respondent)"
putexcel A10 = "Female"
putexcel A11 = "Age"
putexcel A12 = "Married (monogamous)"
putexcel A13 = "Married (polygamous)"
putexcel A14 = "Years of education"
putexcel A15 = "Sample size"

putexcel A17:E17, italic border(bottom)
putexcel A17 = "Other adults (proxied respondents)"
putexcel A18 = "Female"
putexcel A19 = "Age"
putexcel A20 = "Married (monogamous)"
putexcel A21 = "Married (polygamous)"
putexcel A22 = "Years of education"
putexcel A23 = "Sample size"
putexcel A23:E23, border(bottom, double)

putexcel B4:E6, nformat(0.000)
putexcel B10:E14, nformat(0.000)
putexcel B18:E22, nformat(0.000)
putexcel B4:E23, hcenter

mata: b = xl()
mata: b.load_book("$output\tables_seasonality_paper.xlsx")
mata: b.set_sheet("Table1")
mata: b.set_column_width(1,1,25)
mata: b.set_column_width(2,30,12)



*Table 2
use "$data/long_final.dta", clear
drop if treatment == 0

local cluster hhid

tab treatment, gen(treat)

keep if panel == 1

gen panel_person = 1 if panel == 1
replace panel_person = 0 if (hhmem__r1 == 3 | hhmem__r2 == 3 | hhmem__r3 == 3 | hhmem__r4 == 3) & panel == 1
replace panel_person = 0 if missing(hhmem__r4) & panel_person == 1

drop if panel_person == 0


gen samp1 = 1 if pid == 1 & treatment != 0
*gen samp2 = 1 if pid == 1 & inRD1 == 1
*gen samp3 = 1 if pid == 1 & inRD2 == 1
*gen samp4 = 1 if pid == 1 & inRD3 == 1
*gen samp5 = 1 if pid == 1 & inRD4 == 1
gen samp2 = 1 /*if pid == 1 & panel == 1 & panel_person == 1 */
gen samp3 = 1 if /*pid == 1 & panel == 1 & panel_person == 1 & */ treatment == 1
gen samp4 = 1 if /*pid == 1 & panel == 1 & panel_person == 1 & */ treatment == 2


	gen longrecall = 0
	replace longrecall = 1 if recall=="12m"
	*gen proxy = pid != 1																// confirm later, placeholder assuming respondent is in pid==1, but might not be true
	gen first3m = 0
	replace first3m = 1 if treatment == 1

	gen keep = .
	replace keep = 1 if first3m == 0 & longrecall == 1
	replace keep = 1 if first3m == 1 & longrecall == 0
	*keep if (first3m==0 & longrecall==1) | (first3m==1 & longrecall==0)

	keep if keep == 1

putexcel set "$output\tables_seasonality_paper.xlsx", sheet("Table2") modify 

	foreach var in worked_qb numjobtotb worked_nummnths_qb hours_qb type_hhf_qb type_hhb_qb type_wage_qb {
	    rename `var'_ `var'
	}

forvalues i = 3/4 {
    
	if `i' == 3 {
	    local col = "B"
	}
	if `i' == 4 {
	    local col = "C"
	}

	
	local j = 3
	foreach var in worked_qb numjobtotb worked_nummnths_qb hours_qb type_hhf_qb type_hhb_qb type_wage_qb {
	    
		if `i' >= 3 & `i' <= 4 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}

			local j = `j' + 1		
		}
		
	
	}
			
	
putexcel A1:C1, merge 
putexcel A1:C1, hcenter bold border(bottom)
putexcel A2:C2, hcenter vcenter txtwrap
putexcel A1 = "Table 2: Outcome variables"
putexcel B2 = "Short recall"	
putexcel C2 = "Long recall"	

putexcel A3 = "Worked at all"
putexcel A4 = "Total activities"
putexcel A5 = "Number of months worked"
putexcel A6 = "Hours worked (100s)"
putexcel A7 = "Worked hh farm/ag"
putexcel A8 = "Worked non ag business"
putexcel A9 = "Worked wage"


putexcel A9:C9, border(bottom, double)

putexcel B3:C9, nformat(0.000)
putexcel B3:C9, hcenter

mata: b = xl()
mata: b.load_book("$output\tables_seasonality_paper.xlsx")
mata: b.set_sheet("Table2")
mata: b.set_column_width(1,1,25)
mata: b.set_column_width(2,30,12)

	
	

	
	
	
	
	
	
	
	