

use "$data/merged_long_data_attrit.dta", clear
drop if treatment == 0

local cluster hhid

tab treatment, gen(treat)

gen female = 1 if gender == 0
replace female = 0 if gender == 1

gen panel_person = 1 if panel == 1
replace panel_person = 0 if (hhmem__r1 == 3 | hhmem__r2 == 3 | hhmem__r3 == 3 | hhmem__r4 == 3) & panel == 1
replace panel_person = 0 if missing(hhmem__r4) & panel_person == 1

gen rel_head = 0 
replace rel_head = 1 if rel_tohead == 1

gen rel_spouse = 0
replace rel_spouse = 1 if rel_tohead == 2

gen rel_child = 0
replace rel_child = 1 if rel_tohead == 3

gen rel_other = 0
replace rel_other = 1 if rel_tohead >= 4


gen married_monog = 0
replace married_monog = 1 if mar_status == 1

gen married_poly = 0
replace married_poly = 1 if mar_status == 2


gen samp1 = 1 if pid == 1 & treatment != 0

gen samp2 = 1 if pid == 1 & panel == 1 & panel_person == 1
gen samp3 = 1 if pid == 1 & panel == 1 & panel_person == 1 & treatment == 1
gen samp4 = 1 if pid == 1 & panel == 1 & panel_person == 1 & treatment == 2


*Table 1 - Main sum stats*
putexcel set "$output\tables_seasonality_paper.xlsx", sheet("TableA1") modify 

forvalues i = 1/2 {
    
	if `i' == 2 {
	    local col = "B"
	}
	if `i' == 1 {
	    local col = "C"
	}

	local j = 10
	foreach var in female age married_monog married_poly school_years {
	    
		if `i' >= 1 & `i' <= 2 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}

			local j = `j' + 1		
		}
		
		if `i' >= 1 & `i' <= 2 {

			sum female if samp`i' == 1
			putexcel `col'`j' = `r(N)'
		}
		
	}


	
drop samp*
gen samp1 = 1 if pid != 1 & treatment != 0

gen samp2 = 1 if pid != 1 & panel == 1 & panel_person == 1
gen samp3 = 1 if pid != 1 & panel == 1 & panel_person == 1 & treatment == 1
gen samp4 = 1 if pid != 1 & panel == 1 & panel_person == 1 & treatment == 2
 

 

forvalues i = 1/2 {
    
	if `i' == 2 {
	    local col = "B"
	}
	if `i' == 1 {
	    local col = "C"
	}


	
	local j = 18
	foreach var in female age married_monog married_poly school_years {
	    
		if `i' >= 1 & `i' <= 2 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}

			local j = `j' + 1		
		}
		
		if `i' >= 1 & `i' <= 2 {

			sum female if samp`i' == 1
			putexcel `col'`j' = `r(N)'
		}
		
	}



use "$data/merged_data_attrit.dta", clear

drop if treatment == 0

local cluster hhid

tab treatment, gen(treat)

gen samp1 = 1 if treatment != 0

gen samp2 = 1 if panel == 1
gen samp3 = 1 if panel == 1 & treatment == 1
gen samp4 = 1 if panel == 1 & treatment == 2

forvalues i = 1/2 {
    
	if `i' == 2 {
	    local col = "B"
	}
	if `i' == 1 {
	    local col = "C"
	}
	
	
	local j = 4
	foreach var in hhsize numadults numchildren {
	    
		if `i' >= 1 & `i' <= 2 {
		
			sum `var' if samp`i' == 1
			*scalar `var'_`i' = r(mean)			
			putexcel `col'`j' = `r(mean)'
		}

			local j = `j' + 1		
		}
		
		if `i' >= 1 & `i' <= 2 {

			sum hhsize if samp`i' == 1
			putexcel `col'`j' = `r(N)'
		}
		
	}


putexcel A1:C1, merge 
putexcel A1:C1, hcenter bold border(bottom)
putexcel A2:C2, hcenter vcenter txtwrap
putexcel A1 = "Appendix Table 1: Sample Selection"

putexcel B2 = "Full panel analysis sample"	
putexcel C2 = "Targeted MRALS sample"	
	
putexcel A3:C3, italic border(bottom)
putexcel A3 = "Households"
putexcel A4 = "Household size"
putexcel A5 = "Number of adults"
putexcel A6 = "Number of children"
putexcel A7 = "Sample size"

putexcel A9:C9, italic border(bottom)
putexcel A9 = "Household head (designated respondent)"
putexcel A10 = "Female"
putexcel A11 = "Age"
putexcel A12 = "Married (monogamous)"
putexcel A13 = "Married (polygamous)"
putexcel A14 = "Years of education"
putexcel A15 = "Sample size"

putexcel A17:C17, italic border(bottom)
putexcel A17 = "Other adults (proxied respondents)"
putexcel A18 = "Female"
putexcel A19 = "Age"
putexcel A20 = "Married (monogamous)"
putexcel A21 = "Married (polygamous)"
putexcel A22 = "Years of education"
putexcel A23 = "Sample size"
putexcel A23:C23, border(bottom, double)

putexcel B4:C6, nformat(0.000)
putexcel B10:C14, nformat(0.000)
putexcel B18:C22, nformat(0.000)
putexcel B4:C23, hcenter

mata: b = xl()
mata: b.load_book("$output\tables_seasonality_paper.xlsx")
mata: b.set_sheet("TableA1")
mata: b.set_column_width(1,1,25)
mata: b.set_column_width(2,30,12)


